Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NaiveRealIP ¶
NaiveRealIP returns the most real non-private IP address ("closest to client") from input request. Note: This IP can be spoofed by malicious sender, so avoid using it for security purposes
func SecureRealIP ¶
SecureRealIP returns the trusted non-private real IP address from input request. Note: This IP can be trusted only if your server is behind reverse proxy such as AWS ELB/ALB.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.